@@ -471,10 +471,10 @@ deal_with_x_crashes (GdmDisplay *d)
 
 		    /* some promised variables */
 		    g_setenv ("XLOG", xlog, TRUE);
-		    g_setenv ("BINDIR", EXPANDED_BINDIR, TRUE);
-		    g_setenv ("SBINDIR", EXPANDED_SBINDIR, TRUE);
-		    g_setenv ("LIBEXECDIR", EXPANDED_LIBEXECDIR, TRUE);
-		    g_setenv ("SYSCONFDIR", EXPANDED_SYSCONFDIR, TRUE);
+		    g_setenv ("BINDIR", BINDIR, TRUE);
+		    g_setenv ("SBINDIR", SBINDIR, TRUE);
+		    g_setenv ("LIBEXECDIR", LIBEXECDIR, TRUE);
+		    g_setenv ("SYSCONFDIR", GDMCONFDIR, TRUE);
 
 		    /* To enable gettext stuff in the script */
 		    g_setenv ("TEXTDOMAIN", GETTEXT_PACKAGE, TRUE);
@@ -539,7 +539,7 @@ deal_with_x_crashes (GdmDisplay *d)
     /* if we have "open" we can talk to the user, not as user
      * friendly as the above script, but getting there */
     if ( ! just_abort &&
-	g_access (EXPANDED_LIBEXECDIR "/gdmopen", X_OK) == 0) {
+	g_access (LIBEXECDIR "/gdmopen", X_OK) == 0) {
 	    /* Shit if we knew what the program was to tell the user,
 	     * the above script would have been defined and we'd run
 	     * it for them */
@@ -1237,7 +1237,7 @@ struct poptOption options [] = {
 	{ "no-console", '\0', POPT_ARG_NONE,
 	  &no_console, 0, N_("No console (static) servers to be run"), NULL },
 	{ "config", '\0', POPT_ARG_STRING,
-	  &config_file, 0, N_("Alternative configuration file"), N_("CONFIGFILE") },
+	  &config_file, 0, N_("Alternative defaults configuration file"), N_("CONFIGFILE") },
 	{ "preserve-ld-vars", '\0', POPT_ARG_NONE,
 	  &preserve_ld_vars, 0, N_("Preserve LD_* variables"), NULL },
 	{ "version", '\0', POPT_ARG_NONE,
@@ -2821,7 +2821,7 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 	gdm_debug ("Handling user message: '%s'", msg);
 
 	if (gdm_connection_get_message_count (conn) > GDM_SUP_MAX_MESSAGES) {
-		gdm_debug ("Closing connection, %d messages reached");
+		gdm_debug ("Closing connection, %d messages reached", GDM_SUP_MAX_MESSAGES);
 		gdm_connection_write (conn, "ERROR 200 Too many messages\n");
 		gdm_connection_close (conn);
 		return;
@@ -3142,6 +3142,19 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 		g_string_append (msg, "\n");
 		gdm_connection_printf (conn, "OK %s\n", config_file);
 		g_string_free (msg, TRUE);
+	} else if (strcmp (msg, GDM_SUP_GET_CUSTOM_CONFIG_FILE) == 0) {
+		GString *msg;
+		gchar *ret;
+
+		msg = g_string_new ("OK");
+		g_string_append (msg, "\n");
+		ret = gdm_get_custom_config_file ();
+		if (ret)
+			gdm_connection_printf (conn, "OK %s\n", ret);
+		else
+			gdm_connection_write (conn,
+					      "ERROR 1 File not found\n");
+		g_string_free (msg, TRUE);
 	} else if (strcmp (msg, GDM_SUP_QUERY_LOGOUT_ACTION) == 0) {
 		const gchar *sep = " ";
 		GdmDisplay *disp;
