@@ -733,6 +733,9 @@ gdm_set_welcomemsg (void)
 static void
 gdm_read_config (void)
 {
+	/* Read config data in bulk */
+	gdmcomm_comm_bulk_start ();
+
 	gdmcomm_set_debug (gdm_config_get_bool (GDM_KEY_DEBUG));
 
 	/*
@@ -792,12 +795,15 @@ gdm_read_config (void)
 	gdm_config_get_string (GDM_KEY_PID_FILE);
 	gdm_config_get_string (GDM_KEY_PRE_FETCH_PROGRAM);
 
-	gdmcomm_comm_close ();
+	gdmcomm_comm_bulk_stop ();
 }
 
 static gboolean
 greeter_reread_config (int sig, gpointer data)
 {
+	/* Read config data in bulk */
+	gdmcomm_comm_bulk_start ();
+
 	if (gdm_config_reload_bool (GDM_KEY_DEBUG))
 		gdmcomm_set_debug (gdm_config_get_bool (GDM_KEY_DEBUG));
 
@@ -848,7 +854,7 @@ greeter_reread_config (int sig, gpointer data)
 		gdm_common_setup_cursor (GDK_WATCH);
 
 		gdm_wm_save_wm_order ();
-		gdmcomm_comm_close ();
+		gdmcomm_comm_bulk_stop ();
 
 		_exit (DISPLAY_RESTARTGREETER);
 	}
@@ -869,12 +875,12 @@ greeter_reread_config (int sig, gpointer data)
 		gdm_common_setup_cursor (GDK_WATCH);
 
 		gdm_wm_save_wm_order ();
-		gdmcomm_comm_close ();
+		gdmcomm_comm_bulk_stop ();
 
 		_exit (DISPLAY_RESTARTGREETER);
 	}
 
-	gdmcomm_comm_close ();
+	gdmcomm_comm_bulk_stop ();
 
 	return TRUE;
 }
@@ -1302,7 +1308,7 @@ main (int argc, char *argv[])
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
 
-      execl (EXPANDED_LIBEXECDIR "/gdmlogin", EXPANDED_LIBEXECDIR "/gdmlogin", NULL);
+      execl (LIBEXECDIR "/gdmlogin", LIBEXECDIR "/gdmlogin", NULL);
       execlp ("gdmlogin", "gdmlogin", NULL);
 
       dialog = ve_hig_dialog_new (NULL /* parent */,
