@@ -18,8 +18,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "config.h"
+
 #include <ctype.h>
 #include <string.h>
+#include <stdlib.h>
 #include <syslog.h>
 #include <math.h>
 
@@ -28,10 +31,9 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <gnome.h>
+#include <glib/gi18n.h>
 
 #include <X11/Xlib.h>
-#include <config.h>
  
 #ifdef HAVE_XINPUT
 #include <X11/extensions/XInput.h>
@@ -42,7 +44,7 @@
  * if this module is ever moved outside of gdm.
  */
 
-#define CONFIGFILE EXPANDED_SYSCONFDIR "/gdm/modules/AccessDwellMouseEvents"
+#define CONFIGFILE GDMCONFDIR "/modules/AccessDwellMouseEvents"
 #define iseol(ch)       ((ch) == '\r' || (ch) == '\f' || (ch) == '\0' || \
                         (ch) == '\n')
 
@@ -83,7 +85,9 @@ typedef struct {
 
 static int lineno = 0;
 static GSList *binding_list = NULL;
+
 extern char **environ;
+
 static guint enter_signal_id = 0;
 static guint leave_signal_id = 0;
 static int xinput_type_motion = 0;
@@ -115,7 +119,7 @@ is_ext_device (XID id)
 			return TRUE;
 
 	if (debug_gestures)
-		syslog (LOG_WARNING, "is-ext-device failed for %d", id);
+		syslog (LOG_WARNING, "is-ext-device failed for %d", (int) id);
 
 	return FALSE;
 }
@@ -665,7 +669,7 @@ leave_enter_emission_hook (GSignalInvocationHint        *ihint,
 				g_timeout_add (2000, change_cursor_back, NULL);
 				latch_core_pointer = FALSE;
 				/* once we've recognized a gesture, we need to *
-				/* leave the pointer alone */
+				 * leave the pointer alone */
 			}
 		}
 	}
@@ -741,7 +745,7 @@ void gtk_module_init (int *argc, char* argv[])
 
 	if (debug_gestures) {
 		/* If not running under GDM, then need to openlog ourselves */
-		if (!g_getenv ("RUNNING_UNDER_GDM") != NULL)
+		if (g_getenv ("RUNNING_UNDER_GDM") == NULL)
 			openlog ("gesturelistener", LOG_PID, LOG_DAEMON);
 
 		syslog (LOG_WARNING, "dwellmouselistener loaded.");
